<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast" sourcelanguage="en_US">
<context>
    <name>AlbumDefaultPage</name>
    <message>
        <source>Add Songs</source>
        <translation>Añade canciones</translation>
    </message>
    <message>
        <source>Open Folders</source>
        <translation>Abre carpetas</translation>
    </message>
    <message>
        <source>Drag music files here or</source>
        <translation>Arrastra archivos de música aquí o</translation>
    </message>
    <message>
        <source>scan the Music directory</source>
        <translation>escanea el directorio de Música</translation>
    </message>
</context>
<context>
    <name>AlbumGridDelegate</name>
    <message>
        <source>1 song</source>
        <translation>1 canción</translation>
    </message>
    <message>
        <source>%1 songs</source>
        <translation>&apos;%1 canciones&apos;</translation>
    </message>
</context>
<context>
    <name>AlbumListDelegate</name>
    <message>
        <source>%1</source>
        <translation>&apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Rutas</translation>
    </message>
    <message>
        <source>Date added</source>
        <translation>Fecha de añadida</translation>
    </message>
</context>
<context>
    <name>AlbumMoreMenu</name>
    <message>
        <source>View details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <source>Play all</source>
        <translation>Reproducir todas</translation>
    </message>
    <message>
        <source>Add to</source>
        <translation>Añadir a</translation>
    </message>
</context>
<context>
    <name>AlbumSublist</name>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>AlbumSublistDelegate</name>
    <message>
        <source>My Favorites</source>
        <translation>Mis Favoritos</translation>
    </message>
</context>
<context>
    <name>AlbumSublistView</name>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Albums</source>
        <translation>Álbums</translation>
    </message>
    <message>
        <source>%1 albums - %2 songs</source>
        <translation>&apos;%1 álbums - %2 canciones&apos;</translation>
    </message>
</context>
<context>
    <name>AllMusicDefaultPage</name>
    <message>
        <source>Add Songs</source>
        <translation>Todas las Canciones</translation>
    </message>
    <message>
        <source>Open Folders</source>
        <translation>Las canciones favoritas mostrarán aquí.</translation>
    </message>
    <message>
        <source>Drag music files here or</source>
        <translation>Clic “ ♥ ” pa añadir una canción a Mis Favoritos</translation>
    </message>
    <message>
        <source>Your favorite songs will be displayed here.</source>
        <translation>Nun hai canciones. Clic “ ➕ ” pa añadir canciones a la lista de reproducción.</translation>
    </message>
    <message>
        <source>Click“  ♥  ”to add a song to My Favorites</source>
        <translation> escanea el directorio de Música</translation>
    </message>
    <message>
        <source>No songs yet. Click“  ➕  ”to add songs to the playlist.</source>
        <translation>Todo lo de Música</translation>
    </message>
    <message>
        <source> scan the Music directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AllMusicList</name>
    <message>
        <source>All Songs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 songs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AllMusicListDelegate</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AllMusicListView</name>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>ArtistDefaultPage</name>
    <message>
        <source>Add Songs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drag music files here or</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>scan the Music directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ArtistGridDelegate</name>
    <message>
        <source>1 song</source>
        <translation>1 canció</translation>
    </message>
    <message>
        <source>%1 songs</source>
        <translation>%1 canciones</translation>
    </message>
</context>
<context>
    <name>ArtistMoreMenu</name>
    <message>
        <source>View details</source>
        <translation>Ver detalles</translation>
    </message>
    <message>
        <source>Play all</source>
        <translation>Reproducir to</translation>
    </message>
    <message>
        <source>Add to</source>
        <translation>Añadir a</translation>
    </message>
</context>
<context>
    <name>ArtistSublistDelegate</name>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
</context>
<context>
    <name>ArtistSublistView</name>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <source>%1 artists - %2 songs</source>
        <translation>%1 artistas - %2 canciones</translation>
    </message>
</context>
<context>
    <name>CDRemovedDialog</name>
    <message>
        <source>The CD has been removed</source>
        <translation>El CD foi elimináu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <source>Please choose your action</source>
        <translation>Por favor, elige la acción</translation>
    </message>
    <message>
        <source>Minimize to system tray</source>
        <translation>Minimizar a la bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Do not ask again</source>
        <translation>Non pedir nuevamente</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>CurrentPlayList</name>
    <message>
        <source>Play queue</source>
        <translation>Cola de reproducción</translation>
    </message>
    <message>
        <source>1 song</source>
        <translation>1 canció</translation>
    </message>
    <message>
        <source>%1 songs</source>
        <translation>%1 canciones</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Balero</translation>
    </message>
</context>
<context>
    <name>CurrentPlayListDelegate</name>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
</context>
<context>
    <name>CustomPlaylistModel</name>
    <message>
        <source>My Favorites</source>
        <translation>Mis favoritos</translation>
    </message>
    <message>
        <source>CD playlist</source>
        <translation>Lista de reproducción del CD</translation>
    </message>
    <message>
        <source>CD</source>
        <translation>CD</translation>
    </message>
</context>
<context>
    <name>DeleteLocalDialog</name>
    <message>
        <source>Are you sure you want to delete %1?</source>
        <translation>¿Estas seguru de que quier borrar %1?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation>¿Estas seguru de que quier borrar les seleccions %1 canciones?</translation>
    </message>
    <message>
        <source>The song files contained will also be deleted</source>
        <translation>Los ficheros de canciones incluyíos serán tamién borrados</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>DeleteSonglistDialog</name>
    <message>
        <source>Are you sure you want to remove %1?</source>
        <translation>¿Estas seguru de que quier eliminar %1?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected %1 songs?</source>
        <translation>¿Estas seguru de que quier eliminar les seleccions %1 canciones?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>¿Estas seguru de que quier borrar esta lista de reproducción?</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <source>Custom</source>
        <translation>Personalizáu</translation>
    </message>
    <message>
        <source>Monophony</source>
        <translation>Monofonía</translation>
    </message>
    <message>
        <source>Classical</source>
        <translation>Clásica</translation>
    </message>
    <message>
        <source>Club</source>
        <translation>Club</translation>
    </message>
    <message>
        <source>Dance</source>
        <translation>Dance</translation>
    </message>
    <message>
        <source>Full Bass</source>
        <translation>Bass completu</translation>
    </message>
    <message>
        <source>Full Bass and Treble</source>
        <translation>Bass completu y Treble completu</translation>
    </message>
    <message>
        <source>Full Treble</source>
        <translation>Treble completu</translation>
    </message>
    <message>
        <source>Headphones</source>
        <translation>Auriculares</translation>
    </message>
    <message>
        <source>Hall</source>
        <translation>الهول</translation>
    </message>
    <message>
        <source>Live</source>
        <translation>En direutu</translation>
    </message>
    <message>
        <source>Party</source>
        <translation>Folixa</translation>
    </message>
    <message>
        <source>Pop</source>
        <translation>Pop</translation>
    </message>
    <message>
        <source>Reggae</source>
        <translation>Reggae</translation>
    </message>
    <message>
        <source>Rock</source>
        <translation>Rock</translation>
    </message>
    <message>
        <source>Ska</source>
        <translation>Ska</translation>
    </message>
    <message>
        <source>Soft</source>
        <translation>Suave</translation>
    </message>
    <message>
        <source>Soft Rock</source>
        <translation>الروك الطرية</translation>
    </message>
    <message>
        <source>Techno</source>
        <translation>التكنو</translation>
    </message>
    <message>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reaniciar</translation>
    </message>
    <message>
        <source>Preamplifier</source>
        <translation>المُقدّم</translation>
    </message>
</context>
<context>
    <name>ImportFailedDialog</name>
    <message>
        <source>Import failed, no valid music file found</source>
        <translation>فشل الاستيراد، لم يتم العثور على ملف موسيقي صحيح</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
</context>
<context>
    <name>ImportMenu</name>
    <message>
        <source>Play queue</source>
        <translation>قائمة التشغيل</translation>
    </message>
    <message>
        <source>My favorites</source>
        <translation>Los mios favoritos</translation>
    </message>
    <message>
        <source>Create new playlist</source>
        <translation>إنشاء قائمة تشغيل جديدة</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
</context>
<context>
    <name>LyricPage</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>No lyrics found</source>
        <translation>لم يتم العثور على كلمات</translation>
    </message>
    <message>
        <source>Please put the lyric file (same name as the song) and the song file in the same folder</source>
        <translation>يرجى وضع ملف الكلمات (نفس الاسم الذي تم تعيينه للموسيقى) وملف الموسيقى في المجلد نفسه</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Already added to the playlist</source>
        <translation>تم إضافته بالفعل إلى القائمة</translation>
    </message>
    <message>
        <source>Added to &quot;%1&quot;</source>
        <translation>تم إضافته إلى &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Removed from &quot;My Favorites&quot;</source>
        <translation>تم إزالته من &quot;المفضلة&quot; </translation>
    </message>
    <message>
        <source>A disc is connected</source>
        <translation>تم توصيل محرك أقراص</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>All Songs</source>
        <translation>جميع الأغاني</translation>
    </message>
</context>
<context>
    <name>MulitSelectMenu</name>
    <message>
        <source>Add to</source>
        <translation>أضف إلى</translation>
    </message>
    <message>
        <source>Remove from playlist</source>
        <translation>Desaniciar del llistáu de reproducción</translation>
    </message>
    <message>
        <source>Delete from local disk</source>
        <translation>Desaniciar del discu llocal</translation>
    </message>
</context>
<context>
    <name>MusicBaselistview</name>
    <message>
        <source>Library</source>
        <translation>Fonoteca</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>الألبومات</translation>
    </message>
    <message>
        <source>Artists</source>
        <translation>الفنانين</translation>
    </message>
    <message>
        <source>All Songs</source>
        <translation>جميع الأغاني</translation>
    </message>
    <message>
        <source>Playlists</source>
        <translation>القوائم</translation>
    </message>
    <message>
        <source>Create playlist</source>
        <translation>أنشئ قائمة تشغيل</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
</context>
<context>
    <name>MusicContentWindow</name>
    <message>
        <source>My Favorites</source>
        <translation>المفضلة</translation>
    </message>
</context>
<context>
    <name>MusicInfoDialog</name>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Triba</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamañu</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Camín</translation>
    </message>
</context>
<context>
    <name>MusicMoreMenu</name>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Add to</source>
        <translation>أضف إلى</translation>
    </message>
    <message>
        <source>Open in file manager</source>
        <translation>Abrir nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Remove from playlist</source>
        <translation>Desaniciar del llistáu de reproducción</translation>
    </message>
    <message>
        <source>Delete from local disk</source>
        <translation>Desaniciar del discu llocal</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <source>Song info</source>
        <translation>Informaciónd de canción</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>Music هو جهاز تشغيل موسيقي محلي يتميز بتصميم جميل ووظائف بسيطة.</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Unknown album</source>
        <translation>Álbum desconocíu</translation>
    </message>
    <message>
        <source>Unknown artist</source>
        <translation>Artista desconocíu</translation>
    </message>
</context>
<context>
    <name>SearchResultDialog</name>
    <message>
        <source>Songs</source>
        <translation>الأغاني</translation>
    </message>
    <message>
        <source>Artists</source>
        <translation>الفنانين</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>الألبومات</translation>
    </message>
</context>
<context>
    <name>SearchResultWindow</name>
    <message>
        <source>No search results</source>
        <translation>Nun hai resultaos de gueta</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>نتائج البحث</translation>
    </message>
    <message>
        <source>%1 albums - %2 songs</source>
        <translation>&apos;%1 ألبومات - %2 أغاني&apos;</translation>
    </message>
    <message>
        <source>1 album - 1 song</source>
        <translation>1 ألبوم - 1 أغنية</translation>
    </message>
    <message>
        <source>%1 album - %2 songs</source>
        <translation>%1 ألبوم - %2 أغاني</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Autoplay</source>
        <translation>Auto-reproducción</translation>
    </message>
    <message>
        <source>Remember playback position on exit</source>
        <translation>تذكّر مكان التشغيل عند الخروج</translation>
    </message>
    <message>
        <source>Enable fade in/out</source>
        <translation>تمكين التدرج في الدخول والخروج</translation>
    </message>
    <message>
        <source>Close Main Window</source>
        <translation>Zarrar ventana principal</translation>
    </message>
    <message>
        <source>Minimize to system tray</source>
        <translation>Minimizar a la bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>اسأله لي دائمًا</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atayos</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Xubir volume</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Baxar volume</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضل</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Trocar</translation>
    </message>
    <message>
        <source>This shortcut key conflicts with [%1], click Replace to make this shortcut key take effect immediately</source>
        <translation>هذا المفتاح القصير يتعارض مع [%1]، انقر على استبدال لجعل هذا المفتاح القصير يصبح فعالًا فورًا</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Songs</source>
        <translation>الأغاني</translation>
    </message>
    <message>
        <source>Playlists</source>
        <translation>القوائم</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Xubir volume</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Baxar volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضل</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>الغاء المفضل</translation>
    </message>
    <message>
        <source>Song info</source>
        <translation>Informaciónd de canción</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <source>Add music</source>
        <translation>Amestar música</translation>
    </message>
    <message>
        <source>Rename playlist</source>
        <translation>إعادة تسمية القائمة</translation>
    </message>
    <message>
        <source>Remove from playlist</source>
        <translation>Desaniciar del llistáu de reproducción</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atayos</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>أحذي الأغاني</translation>
    </message>
</context>
<context>
    <name>SidebarMenu</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Add songs</source>
        <translation>أضف أغاني</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>SortMenu</name>
    <message>
        <source>CD playlist</source>
        <translation>قائمة CD</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizáu</translation>
    </message>
    <message>
        <source>Date added</source>
        <translation>التاريخ المضافة</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
</context>
<context>
    <name>SublistTitleButton</name>
    <message>
        <source>1 song</source>
        <translation>1 أغنية</translation>
    </message>
    <message>
        <source>%1 songs</source>
        <translation>%1 أغاني</translation>
    </message>
    <message>
        <source>Play All</source>
        <translation>Reproducir too</translation>
    </message>
</context>
<context>
    <name>ToolButtonItem</name>
    <message>
        <source>Play All</source>
        <translation>Reproducir too</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Sequential play</source>
        <translation>التشغيل المتسلسل</translation>
    </message>
    <message>
        <source>List loop</source>
        <translation>التشغيل المتكرر للقائمة</translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation>التشغيل المتكرر للعنصر</translation>
    </message>
    <message>
        <source>Shuffle</source>
        <translation>Al debalu</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>الغاء المفضل</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضل</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>أحذي الأغاني</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Lyrics</source>
        <translation>Lletres</translation>
    </message>
    <message>
        <source>Play Queue</source>
        <translation>التشغيل المُرتّب</translation>
    </message>
</context>
<context>
    <name>WindowTitlebar</name>
    <message>
        <source>Add playlist</source>
        <translation>أضف قائمة</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <source>Add music</source>
        <translation>Amestar música</translation>
    </message>
    <message>
        <source>Equalizer</source>
        <translation>Ecualizador</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>Music هو مُشغل موسيقى محلي بتصميم جميل ووظائف بسيطة.</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Previous page</source>
        <translation>الصفحة السابقة</translation>
    </message>
    <message>
        <source>Next page</source>
        <translation>الصفحة التالية</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
    <message>
        <source>%1 is released under %2</source>
        <translation>%1 تم الإصدار بموجب %2</translation>
    </message>
</context>
</TS>
